@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries without C or XS
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -100,12 +100,12 @@ sub type
 
   croak "alias conflicts with existing type" if defined $alias && (defined $type_map->{$alias} || defined $self->{types}->{$alias});
 
-  if($name =~ /-\>/)
+  if($name =~ /-\>/ || $name =~ /^record\s*\([0-9A-Z:a-z_]+\)$/)
   {
-    # for closure types we do not try to convet into the basic type
-    # so you can have many many many copies of a given closure type
-    # if you do not spell it exactly the same each time.  Recommended
-    # thsat you use an alias for a closure type anyway.
+    # for closure and record types we do not try to convet into the
+    # basic type so you can have many many many copies of a given
+    # closure type if you do not spell it exactly the same each time.
+    # Recommended that you use an alias for a closure type anyway.
     $self->{types}->{$name} ||= FFI::Platypus::Type->new($name, $self);
   }
   else
@@ -214,7 +214,7 @@ sub type_meta
 {
   my($self, $name) = @_;
   $self = $self->new unless ref $self && eval { $self->isa('FFI::Platypus') };
-  my $type = $self->_type_lookup($name);
+  my $type = $self->{types}->{$name} || $self->_type_lookup($name);
   $type->meta;
 }
 
@@ -280,9 +280,9 @@ sub attach_cast
 
 sub sizeof
 {
-  my($self,$type) = @_;
-  $self->type($type);
-  $self->type_meta($type)->{size};
+  my($self,$name) = @_;
+  my $type = $self->{types}->{$name} || $self->_type_lookup($name);
+  FFI::Platypus::Type::sizeof($type);
 }
 
 
@@ -348,7 +348,7 @@ sub DESTROY
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -360,7 +360,7 @@ package FFI::Platypus::Closure;
 use Scalar::Util qw( refaddr);
 use Carp qw( croak );
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 our %cbdata;
 
@@ -387,13 +387,13 @@ sub DESTROY
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 sub new
 {
@@ -412,15 +412,45 @@ sub new
   
   my $ffi_type;
   my $platypus_type;
-  my $array_size = 0;
+  my $array_or_record_size = 0;
+  my $classname;
   
   if($type eq 'string')
   {
     $ffi_type = 'pointer';
     $platypus_type = 'string';
   }
-  elsif($type =~ s/\s+\*$//)
+  elsif($type =~ /^record\s*\(([0-9:A-Za-z_]+)\)$/)
   {
+    $ffi_type = 'pointer';
+    $platypus_type = 'record';
+    if($1 =~ /^([0-9]+)$/)
+    {
+      $array_or_record_size = $1;
+    }
+    else
+    {
+      $classname = $1;
+      unless($classname->can('ffi_record_size') || $classname->can('_ffi_record_size'))
+      {
+        eval qq{ require $classname };
+        warn "error requiring $classname: $@";
+      }
+      if($classname->can('ffi_record_size'))
+      {
+        $array_or_record_size = $classname->ffi_record_size;
+      }
+      elsif($classname->can('_ffi_record_size'))
+      {
+        $array_or_record_size = $classname->_ffi_record_size;
+      }
+      else
+      {
+        croak "$classname has not ffi_record_size or _ffi_record_size method";
+      }
+    }
+  }
+  elsif($type =~ s/\s+\*$//) {
     $ffi_type = $type;
     $platypus_type = 'pointer';
   }
@@ -428,7 +458,7 @@ sub new
   {
     $ffi_type = $type;
     $platypus_type = 'array';
-    $array_size = $1;
+    $array_or_record_size = $1;
   }
   else
   {
@@ -436,7 +466,7 @@ sub new
     $platypus_type = 'ffi';
   }
   
-  $class->_new($ffi_type, $platypus_type, $array_size);
+  $class->_new($ffi_type, $platypus_type, $array_or_record_size, $classname);
 }
 
 1;
@@ -453,7 +483,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries without C or XS
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -513,8 +543,8 @@ XS is implemented primarily as a bunch of C macros, which requires at
 least some understanding of C, (sadly) the C pre-processor, and some C++ 
 caveats (since on some platforms Perl is compiled and linked with a C++ 
 compiler). Platypus on the other hand could be used to call other 
-compiled languages, like Rust, Go or even assembly, allowing you to 
-focus on your strengths.
+compiled languages, like Fortran, Rust, Go or even assembly, allowing 
+you to focus on your strengths.
 
 =item FFI / Platypus does not require a parser
 
@@ -528,8 +558,7 @@ language that you want to interface with is a bit of an anti-pattern.
 This document consists of an API reference, a set of examples, some 
 support and development (for contributors) information.  If you are new 
 to Platypus or FFI, you may want to skip down to the 
-L<EXAMPLES|FFI::Platypus#EXAMPLES> to get a taste of what you can do 
-with Platypus.
+L<EXAMPLES|/EXAMPLES> to get a taste of what you can do with Platypus.
 
 Platypus also provides an declarative interface you may want to use 
 instead of the object oriented interface called 
@@ -553,7 +582,7 @@ only, so you do not need to worry about stepping on the toes of other
 CPAN FFI / Platypus Authors.
 
 Any functions found will be out of the list of libraries specified with 
-the L<lib|FFI::Platypus#lib> attribute.
+the L<lib|/lib> attribute.
 
 =head3 options
 
@@ -562,13 +591,13 @@ the L<lib|FFI::Platypus#lib> attribute.
 =item lib
 
 Either a pathname (string) or a list of pathnames (array ref of strings) 
-to pre-populate the L<lib|FFI::Platypus#lib> attribute.
+to pre-populate the L<lib|/lib> attribute.
 
 =item ignore_not_found
 
 [version 0.15]
 
-Set the L<ignore_not_found|FFI::Platypus#ignore_not_found> attribute.
+Set the L<ignore_not_found|/ignore_not_found> attribute.
 
 =back
 
@@ -609,16 +638,14 @@ it turns out it is different just about everywhere!).
  $ffi->ignore_not_found(1);
  my $ignore_not_found = $ffi->ignore_not_found;
 
-Normally the L<attach|FFI::Platypus#attach> and 
-L<function|FFI::Platypus#function> methods will throw an exception if it 
-cannot find the name of the function you provide it.  This will change 
-the behavior such that L<function|FFI::Platypus#function> will return 
-C<undef> when the function is not found and 
-L<attach|FFI::Platypus#attach> will ignore functions that are not found. 
+Normally the L<attach|/attach> and L<function|/function> methods will 
+throw an exception if it cannot find the name of the function you 
+provide it.  This will change the behavior such that 
+L<function|/function> will return C<undef> when the function is not 
+found and L<attach|/attach> will ignore functions that are not found. 
 This is useful when you are writing bindings to a library and have many 
 optional functions and you do not wish to wrap every call to 
-L<function|FFI::Platypus#function> or L<attach|FFI::Platypus#attach> in 
-an C<eval>.
+L<function|/function> or L<attach|/attach> in an C<eval>.
 
 =head1 METHODS
 
@@ -670,7 +697,7 @@ prepended to it.
 Returns the list of types that FFI knows about.  This will include the 
 native C<libffi> types (example: C<sint32>, C<opaque> and C<double>) and 
 the normal C types (example: C<unsigned int>, C<uint32_t>), any types 
-that you have defined using the L<type|FFI::Platypus#type> method, and
+that you have defined using the L<type|/type> method, and
 custom types.
 
 The list of types that Platypus knows about varies somewhat from 
@@ -712,7 +739,7 @@ of a performance penalty you can get one like this:
  my $coderef = sub { $function->(@_) };
 
 It may be better, and faster to create a real Perl function using the 
-L<attach|FFI::Platypus#attach> method.
+L<attach|/attach> method.
 
 In addition to looking up a function by name you can provide the address 
 of the symbol yourself:
@@ -720,8 +747,8 @@ of the symbol yourself:
  my $address = $ffi->find_symbol('my_functon');
  my $function = $ffi->function($address => ...);
 
-Under the covers, L<function|FFI::Platypus#function> uses 
-L<find_symbol|FFI::Platypus#find_symbol> when you provide it with a 
+Under the covers, L<function|/function> uses 
+L<find_symbol|/find_symbol> when you provide it with a 
 name, but it is useful to keep this in mind as there are alternative 
 ways of obtaining a functions address.  Example: a C function could 
 return the address of another C function that you might want to call, or 
@@ -740,7 +767,7 @@ Examples:
  $ffi->attach([$address => $perl_name] => \@argument_types => $return_type);
 
 Find and attach a C function as a real live Perl xsub.  The advantage of 
-attaching a function over using the L<function|FFI::Platypus#function> 
+attaching a function over using the L<function|/function> 
 method is that it is much much much faster since no object resolution 
 needs to be done.  The disadvantage is that it locks the function and 
 the L<FFI::Platypus> instance into memory permanently, since there is no 
@@ -750,7 +777,7 @@ If just one I<$name> is given, then the function will be attached in
 Perl with the same name as it has in C.  The second form allows you to 
 give the Perl function a different name.  You can also provide an 
 address (the third form), just like with the 
-L<function|FFI::Platypus#function> method.
+L<function|/function> method.
 
 Examples:
 
@@ -932,7 +959,7 @@ B<Discussion>: libuuid is a library used to generate unique identifiers
 library is or was part of the Linux e2fsprogs package.
 
 Knowing the size of objects is sometimes important.  In this example, we 
-use the L<sizeof|FFI::Platypus#sizeof> function to get the size of 16 
+use the L<sizeof|/sizeof> function to get the size of 16 
 characters (in this case it is simply 16 bytes).  We also know that the 
 strings "deparsed" by C<uuid_unparse> are exactly 37 bytes.
 
@@ -1025,7 +1052,7 @@ handled seamlessly by Platypus.
 B<Discussion>: Sometimes you will have a pointer to a function from a 
 source other than Platypus that you want to call.  You can use that 
 address instead of a function name for either of the 
-L<function|FFI::Platypus#function> or L<attach|FFI::Platypus#attach> 
+L<function|/function> or L<attach|/attach> 
 methods.  In this example we use L<FFI::TinyCC> to compile a short piece 
 of C code and to give us the address of one of its functions, which we 
 then use to create a perl xsub to call it.
@@ -1234,6 +1261,76 @@ inherited from and extended just like any Perl classes because of the
 way the custom types are implemented.  For more details on custom types 
 see L<FFI::Platypus::Type> and L<FFI::Platypus::API>.
 
+=head2 bzip2
+
+ use FFI::Platypus;
+ use FFI::CheckLib qw( find_lib_or_die );
+ use FFI::Platypus::Buffer qw( scalar_to_buffer buffer_to_scalar );
+ use FFI::Platypus::Memory qw( malloc free );
+ 
+ my $ffi = FFI::Platypus->new;
+ $ffi->lib(find_lib_or_die lib => 'bz2');
+ 
+ $ffi->attach(
+   BZ2_bzBuffToBuffCompress => [
+     'opaque',				# dest
+     'unsigned int *',			# dest length
+     'opaque',				# source
+     'unsigned int',			# source length
+     'int',				# blockSize100k
+     'int',				# verbosity
+     'int',				# workFactor
+   ] => 'int',
+ );
+ 
+ $ffi->attach(
+   BZ2_bzBuffToBuffDecompress => [
+     'opaque',				# dest
+     'unsigned int *',			# dest length
+     'opaque',				# source
+     'unsigned int',			# source length
+     'int',				# small
+     'int',				# verbosity
+   ] => 'int',
+ );
+ 
+ sub compress ($)
+ {
+   my($source,$source_length) = scalar_to_buffer($_[0]);
+   my $dest_length = int(length($source)*1.01) + 1 + 600;
+   my $dest = malloc $dest_length;
+   my $r = BZ2_bzBuffToBuffCompress($dest, \$dest_length, $source, $source_length, 9, 0, 30);
+   die "bzip2 error $r" unless $r == 0;
+   my $compressed = buffer_to_scalar($dest, $dest_length);
+   free $dest;
+   $compressed;
+ };
+ 
+ sub decompress ($$)
+ {
+   my($source, $source_length) = scalar_to_buffer($_[0]);
+   my $dest_length = $_[1];
+   my $dest = malloc $dest_length;
+   my $r = BZ2_bzBuffToBuffDecompress($dest, \$dest_length, $source, $source_length, 0, 0);
+   die "bzip2 error $r" unless $r == 0;
+   my $decompressed = buffer_to_scalar($dest, $dest_length);
+ }
+ 
+ my $original = "hello compression world\n";
+ my $compressed = compress $original;
+ print decompress $compressed, length $original;
+
+B<Discussion>: bzip2 is a compression library.  For simple one shot
+attempts at compression/decompression when you expect the original
+and the result to fit within memory it provides two convenience functions
+C<BZ2_bzBuffToBuffCompress> and C<BZ2_bzBuffToBuffDecompress>.
+
+The first four arguments of both of these functions are identical, and 
+represent two buffers.  For the destination buffer, the length is passed 
+in as an pointer to an integer.  The value of this integer going in is 
+the maximum size of the buffer (the amount of memory preallocated).  On 
+output, the bzip2 library updates it with the actual number of bytes used.
+
 =head1 SUPPORT
 
 If something does not work the way you think it should, or if you have a 
@@ -1305,10 +1402,10 @@ a debugging Perl.
  
  
  DEBUG:
-   + $Config{lddlflags} = -shared -O2 -L/usr/local/lib -fstack-protector
-   - $Config{lddlflags} = -shared -g3 -L/usr/local/lib -fstack-protector
-   + $Config{optimize} = -O2
-   - $Config{optimize} = -g3
+   - $Config{lddlflags} = -shared -O2 -L/usr/local/lib -fstack-protector
+   + $Config{lddlflags} = -shared -g3 -L/usr/local/lib -fstack-protector
+   - $Config{optimize} = -O2
+   + $Config{optimize} = -g3
  
  
  Created MYMETA.yml and MYMETA.json
@@ -1391,7 +1488,7 @@ An interface for interacting with C C<struct> types.  Unfortunately it
 appears to be unmaintained, and has a failing pod test, so I cannot 
 recommend it for use by CPAN modules.
 
-=item L<pack|perlfunc#pack> and L<unpack|perlfunc#unpack>
+=item L<pack and unpack|perlpacktut>
 
 Native to Perl functions that can be used to decode C C<struct> types.
 
@@ -1429,7 +1526,11 @@ Another FFI for Perl that doesn't appear to have worked for a long time.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
