@@ -7,7 +7,7 @@ use base qw( Exporter );
 our @EXPORT = qw( scalar_to_buffer buffer_to_scalar );
 
 # ABSTRACT: Convert scalars to C buffers
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 use constant _incantation => 
@@ -41,7 +41,7 @@ FFI::Platypus::Buffer - Convert scalars to C buffers
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -57,8 +57,8 @@ memory region.  In Perl the equivalent structure is a scalar containing
 a string of bytes.  This module provides portable functions for 
 converting a Perl string or scalar into a buffer and back.
 
-These functions are implemented using L<pack|perlfunc#pack> and 
-L<unpack|perlfunc#unpack> so they should be relatively fast.
+These functions are implemented using L<pack and unpack|perlpacktut> and 
+so they should be relatively fast.
 
 Both functions are exported by default, but you can explicitly export 
 one or neither if you so choose.
@@ -103,7 +103,11 @@ Declarative interface to Platypus.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
