@@ -5,7 +5,7 @@ use warnings;
 use FFI::Platypus;
 
 # ABSTRACT: Declarative interface to FFI::Platypus
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 our $ffi    = {};
@@ -143,7 +143,7 @@ FFI::Platypus::Declare - Declarative interface to FFI::Platypus
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -370,7 +370,11 @@ faster.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
