@@ -6,7 +6,7 @@ use FFI::Platypus;
 use base qw( Exporter );
 
 # ABSTRACT: Memory functions for FFI
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 our @EXPORT = qw( malloc free calloc realloc memcpy memset strdup );
@@ -46,7 +46,7 @@ FFI::Platypus::Memory - Memory functions for FFI
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -150,7 +150,11 @@ Declarative interface for Platypus.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
