@@ -6,7 +6,7 @@ use FFI::Platypus;
 use Config ();
 
 # ABSTRACT: Convert a pointer to a string and back
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 use constant _incantation =>
@@ -76,7 +76,7 @@ FFI::Platypus::Type::StringPointer - Convert a pointer to a string and back
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,11 @@ Platypus types documentation.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
