@@ -12,7 +12,7 @@ use Config;
 use base qw( Module::Build );
 
 # ABSTRACT: Build Perl extensions in C with FFI
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 __PACKAGE__->add_property( ffi_libtest_dir =>
@@ -243,7 +243,7 @@ Module::Build::FFI - Build Perl extensions in C with FFI
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -274,17 +274,26 @@ Put your .c and .h files in C<ffi> (C<ffi/example.c>):
    printf("hello world\n");
  }
 
-Attach it to Perl in your main module (C<lib/Foo/Bar.pm>):
+Attach it to Perl in your main module (C<lib/Foo/Bar.pm>) using
+the declarative interface:
 
  package Foo::Bar;
  
  use FFI::Platypus::Declare qw( void );
- use FFI::Util qw( locate_module_share_lib );
  
- lib locate_module_share_lib();
  attach hello_world => [] => void;
 
-Use it from your perl script or module:
+or use the OO interface:
+
+ package Foo::Bar;
+ 
+ use FFI::Platypus;
+ 
+ my $ffi = FFI::Platypus->new;
+ $ffi->package;  # search for symbols in your bundled C code
+ $ffi->attach( hello_world => [] => 'void');
+
+Finally, use it from your perl script or module:
 
  use Foo::Bar;
  Foo::Bar::hello_world();  # prints "hello world\n"
@@ -395,7 +404,11 @@ Microsoft Visual C++, but it may be necessary elsewhere in the future.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
